@@ -1,4 +1,4 @@
-from dataclasses import field as dataclasses_field, make_dataclass
+import types
 from typing import List, Type
 
 import strawberry
@@ -15,16 +15,17 @@ def create_type(name: str, fields: List[StrawberryField]) -> Type:
     >>> Query = create_type(name="Query", fields=[hello])
     """
 
-    if len(fields) == 0:
+    if not fields:
         raise ValueError(f'Can\'t create type "{name}" with no fields')
 
-    dataclass_fields = []
+    namespace = {}
+    annotations = {}
 
     for field in fields:
         if not isinstance(field, StrawberryField):
             raise TypeError("Field is not an instance of StrawberryField")
 
-        if field.graphql_name is None:
+        if field.python_name is None:
             raise ValueError(
                 (
                     "Field doesn't have a name. Fields passed to "
@@ -33,14 +34,11 @@ def create_type(name: str, fields: List[StrawberryField]) -> Type:
                 )
             )
 
-        dataclass_fields.append(
-            (
-                field.graphql_name,
-                field.type,
-                dataclasses_field(default=field),
-            )
-        )
+        namespace[field.python_name] = field
+        annotations[field.python_name] = field.type
 
-    cls = make_dataclass(name, fields=dataclass_fields)
+    namespace["__annotations__"] = annotations  # type: ignore
+
+    cls = types.new_class(name, (), {}, lambda ns: ns.update(namespace))
 
     return strawberry.type(cls)
